ironwood_subtrees

Function ironwood_subtrees 

pub fn ironwood_subtrees<C>(
    chain: Option<C>,
    db: &ZebraDb,
    range: impl RangeBounds<NoteCommitmentSubtreeIndex> + Clone,
) -> BTreeMap<NoteCommitmentSubtreeIndex, NoteCommitmentSubtreeData<Node>>
where C: AsRef<Chain>,
Returns a list of Ironwood NoteCommitmentSubtrees with indexes in the provided range.

If there is no subtree at the first index in the range, the returned list is empty. Otherwise, subtrees are continuous up to the finalized tip.

See subtrees for more details.