ironwood_tree

Function ironwood_tree 

pub fn ironwood_tree<C>(
    chain: Option<C>,
    db: &ZebraDb,
    hash_or_height: HashOrHeight,
) -> Option<Arc<NoteCommitmentTree>>
where C: AsRef<Chain>,
Returns the Ironwood NoteCommitmentTree specified by a hash or height, if it exists in the non-finalized chain or finalized db.

Ironwood reuses the Orchard note commitment tree type, in a separate tree.