pub fn ironwood_tree<C>(
chain: Option<C>,
db: &ZebraDb,
hash_or_height: HashOrHeight,
) -> Option<Arc<NoteCommitmentTree>>Expand description
Returns the Ironwood
NoteCommitmentTree specified by a
hash or height, if it exists in the non-finalized chain or finalized db.
Ironwood reuses the Orchard note commitment tree type, in a separate tree.